==> react-native-web-jsonschema-form-1.1.1.tgz: package/widgets/FileWidget/ProgressHandle.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import View from 'react-native-web-ui-components/View';
import Row from 'react-native-web-ui-components/Row';
import { Helmet, style } from 'react-native-web-ui-components/Helmet';
const styles = StyleSheet.create({
  progress: {
    position: 'absolute',
    top: 29,
    left: 0,
    width: '100%',
    height: 2,
    backgroundColor: 'rgba(200, 200, 200, 0.5)'
  },
  full: {
    height: 2
  },
  error: {
    position: 'absolute',
    top: 0,
    left: 0,
    width: '100%',
    height: '100%',
    backgroundColor: '#FF0000',
    opacity: 0.2,
    borderRadius: 2
  }
});

const ProgressHandle = ({
  meta,
  theme
}) => React.createElement(React.Fragment, null, React.createElement(Helmet, null, React.createElement("style", null, `
          [data-class~="FileWidget__progress"] {
            transition: width 0.5s;
          }
        `)), meta['ui:progress'] !== undefined && meta['ui:progress'] < 100 ? React.createElement(Row, {
  style: styles.progress
}, React.createElement(View, {
  className: "FileWidget__progress",
  style: [styles.full, {
    width: `${meta['ui:progress']}%`,
    backgroundColor: StyleSheet.flatten(theme.input.regular.selected).color
  }]
})) : null, meta['ui:error'] !== undefined ? React.createElement(Row, {
  style: styles.error
}) : null);

ProgressHandle.propTypes = {
  theme: PropTypes.shape().isRequired,
  meta: PropTypes.shape().isRequired
};
export default ProgressHandle;

==> react-native-web-jsonschema-form-2.2.3.tgz: package/widgets/FileWidget/ProgressHandle.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import View from 'react-native-web-ui-components/View';
import Row from 'react-native-web-ui-components/Row';
import { Helmet, style } from 'react-native-web-ui-components/Helmet';
const styles = StyleSheet.create({
  progress: {
    position: 'absolute',
    top: 29,
    left: 0,
    width: '100%',
    height: 2,
    backgroundColor: 'rgba(200, 200, 200, 0.5)'
  },
  full: {
    height: 2
  },
  error: {
    position: 'absolute',
    top: 0,
    left: 0,
    width: '100%',
    height: '100%',
    backgroundColor: '#FF0000',
    opacity: 0.2,
    borderRadius: 2
  }
});

const ProgressHandle = ({
  meta,
  theme
}) => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Helmet, null, /*#__PURE__*/React.createElement("style", null, `
          [data-class~="FileWidget__progress"] {
            transition: width 0.5s;
          }
        `)), meta['ui:progress'] !== undefined && meta['ui:progress'] < 100 ? /*#__PURE__*/React.createElement(Row, {
  style: styles.progress
}, /*#__PURE__*/React.createElement(View, {
  className: "FileWidget__progress",
  style: [styles.full, {
    width: `${meta['ui:progress']}%`,
    backgroundColor: StyleSheet.flatten(theme.input.regular.selected).color
  }]
})) : null, meta['ui:error'] !== undefined ? /*#__PURE__*/React.createElement(Row, {
  style: styles.error
}) : null);

ProgressHandle.propTypes = {
  theme: PropTypes.shape().isRequired,
  meta: PropTypes.shape().isRequired
};
export default ProgressHandle;
